@@ -10,6 +10,7 @@
 #include <X11/Xproto.h>
 #include <X11/Xatom.h>
 #include <stdbool.h>
+#include <array>
 
 #define ENUM_WITH_ALIAS(Identifier, Alias) \
     Identifier, Alias = Identifier
@@ -59,12 +60,26 @@ enum {
     NetCOUNT
 };
 
+// possible values for direction of a _NET_WM_MOVERESIZE client message
+#define _NET_WM_MOVERESIZE_SIZE_TOPLEFT      0
+#define _NET_WM_MOVERESIZE_SIZE_TOP          1
+#define _NET_WM_MOVERESIZE_SIZE_TOPRIGHT     2
+#define _NET_WM_MOVERESIZE_SIZE_RIGHT        3
+#define _NET_WM_MOVERESIZE_SIZE_BOTTOMRIGHT  4
+#define _NET_WM_MOVERESIZE_SIZE_BOTTOM       5
+#define _NET_WM_MOVERESIZE_SIZE_BOTTOMLEFT   6
+#define _NET_WM_MOVERESIZE_SIZE_LEFT         7
+#define _NET_WM_MOVERESIZE_MOVE              8   /* movement only */
+#define _NET_WM_MOVERESIZE_SIZE_KEYBOARD     9   /* size via keyboard */
+#define _NET_WM_MOVERESIZE_MOVE_KEYBOARD    10   /* move via keyboard */
+#define _NET_WM_MOVERESIZE_CANCEL           11   /* cancel operation */
+
 struct HSTag;
 struct HSClient;
 
-Atom g_netatom[NetCOUNT];
+extern Atom g_netatom[NetCOUNT];
 
-extern char* g_netatom_names[];
+extern const std::array<const char*,NetCOUNT> g_netatom_names;
 
 void ewmh_init();
 void ewmh_destroy();
@@ -86,6 +101,8 @@ void ewmh_update_window_state(struct HSClient* client);
 void ewmh_update_frame_extents(Window win, int left, int right, int top, int bottom);
 bool ewmh_is_window_state_set(Window win, Atom hint);
 bool ewmh_is_fullscreen_set(Window win);
+bool ewmh_is_desktop_window(Window win);
+int ewmh_get_window_type(Window win); // returns an element of the NetWm-Enum
 void ewmh_clear_client_properties(struct HSClient* client);
 
 // set the desktop property of a window
