@@ -9,17 +9,18 @@
 #include <X11/Xlib.h>
 #include "glib-backports.h"
 #include <stdbool.h>
+#include <array>
 
-typedef enum Layer {
+enum HSLayer {
     /* layers on each monitor, from top to bottom */
     LAYER_FOCUS,
     LAYER_FULLSCREEN,
     LAYER_NORMAL,
     LAYER_FRAMES,
     LAYER_COUNT,
-} HSLayer;
+};
 
-extern char* g_layer_names[];
+extern const std::array<const char*, LAYER_COUNT> g_layer_names;
 
 typedef enum SliceType {
     SLICE_CLIENT,
@@ -29,7 +30,6 @@ typedef enum SliceType {
 
 struct HSClient;
 struct HSMonitor;
-struct GList;
 
 typedef struct HSSlice {
     HSSliceType type;
